@@ -258,7 +258,7 @@ drake_with_call_stack_8a6af5 <- function(target, config) {
     signalCondition(e)
   }
   expr <- config$spec[[target]]$command_build
-  if (config$settings$lock_envir) {
+  if (config$settings$lock_envir && !isNamespace(config$envir)) {
     on.exit(unlock_environment(config$envir))
     block_envir_lock(config)
     lock_environment(config$envir)
@@ -287,7 +287,7 @@ downsize_error <- function(error) {
 
 # Prevents tracebacks from storing tons of data.
 deparse_traceback <- function(traceback) {
-  vcapply(traceback$calls, safe_deparse)
+  vcapply(traceback$call %|||% traceback$calls, safe_deparse)
 }
 
 block_envir_lock <- function(config) {
